SchemaSpy - Table gnss_data.public.receivers

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.receivers | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
ReceiverCode | varchar | 22 |  |  |  |
stationinfo.ReceiverCode | stationinfo_ReceiverCode_fkey R
ReceiverDescription | varchar | 22 | √ |  | null |  |  |
Table contained 68 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: